# Ellipsis literals

## Python 3.9

```toml
[environment]
python-version = "3.9"
```

```py
reveal_type(...)  # revealed: ellipsis
```

## Python 3.10

```toml
[environment]
python-version = "3.10"
```

```py
reveal_type(...)  # revealed: EllipsisType
```
